##  Right Side Pane of Fact Sheet
The right-side pane of the fact sheet offers quick access to essential additional information and links related to the fact sheet.
It includes:
  * Links to reference catalog items
  * Integration or discovery services (such as ServiceNow or SaaS integrations) to which the fact sheet is connected, along with details like the discovery name, connection status, and external identifiers. This information is visible only to users with access to discovery inboxes, typically administrators, although the permissions can be adjusted. For more, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
  * List of mandatory attributes and their completion status.
  * Recently viewed fact sheets for quick navigation.
  * List of diagrams that the fact sheet is part of, as well as any diagrams that are linked to the fact sheet.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio713ae16c838a428c82dae9009a419d97_LowRes.png)
Right Side Pane Offers Quick Access to Essential Additional Information
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
